summaryrefslogtreecommitdiffstats
path: root/kate/part/kateautoindent.h
diff options
context:
space:
mode:
Diffstat (limited to 'kate/part/kateautoindent.h')
-rw-r--r--kate/part/kateautoindent.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kate/part/kateautoindent.h b/kate/part/kateautoindent.h
index 6c0d15d45..abdab7777 100644
--- a/kate/part/kateautoindent.h
+++ b/kate/part/kateautoindent.h
@@ -190,9 +190,9 @@ class KateAutoIndent : public TQObject
/**
* This action provides a list of available indenters and gets plugged
* into the KateView's KActionCollection.
*/
-class KateViewIndentationAction : public KActionMenu
+class KateViewIndentationAction : public TDEActionMenu
{
Q_OBJECT
@@ -190,9 +190,9 @@ class KateAutoIndent : public TQObject
/**
* This action provides a list of available indenters and gets plugged
- * into the KateView's KActionCollection.
+ * into the KateView's TDEActionCollection.
*/